@@ -27,8 +27,6 @@ logger.setLevel(logging.INFO)
 
 DEFAULT_REF = 'GRCh38'
 
-REF_BUCKET = 'gs://cpg-reference/hg38'
-
 DATAPROC_PACKAGES = [
     'joint-calling',
     'click',
@@ -55,39 +53,6 @@ SM_IMAGE = f'{AR_REPO}/sm-api:2.0.3'
 ALIGNMENT_IMAGE = f'{AR_REPO}/alignment:v4'
 PICARD_IMAGE = f'{AR_REPO}/picard-cloud:2.23.8'
 
-# Reference files
-GATK_REF_BUCKET = f'{REF_BUCKET}/v1'
-REF_FASTA = join(GATK_REF_BUCKET, 'Homo_sapiens_assembly38.fasta')
-UNPADDED_INTERVALS = join(GATK_REF_BUCKET, 'hg38.even.handcurated.20k.intervals')
-NOALT_REGIONS = join(GATK_REF_BUCKET, 'noalt.bed')
-
-GNOMAD_REF_BUCKET = f'{REF_BUCKET}/gnomad/v0'
-TEL_AND_CENT_HT = join(
-    GNOMAD_REF_BUCKET,
-    'telomeres_and_centromeres/hg38.telomeresAndMergedCentromeres.ht',
-)
-LCR_INTERVALS_HT = join(GNOMAD_REF_BUCKET, 'lcr_intervals/LCRFromHengHg38.ht')
-SEG_DUP_INTERVALS_HT = join(GNOMAD_REF_BUCKET, 'seg_dup_intervals/GRCh38_segdups.ht')
-CLINVAR_HT = join(GNOMAD_REF_BUCKET, 'clinvar/clinvar_20190923.ht')
-HAPMAP_HT = join(GNOMAD_REF_BUCKET, 'hapmap/hapmap_3.3.hg38.ht')
-KGP_OMNI_HT = join(GNOMAD_REF_BUCKET, 'kgp/1000G_omni2.5.hg38.ht')
-KGP_HC_HT = join(GNOMAD_REF_BUCKET, 'kgp/1000G_phase1.snps.high_confidence.hg38.ht')
-MILLS_HT = join(
-    GNOMAD_REF_BUCKET, 'mills/Mills_and_1000G_gold_standard.indels.hg38.ht/'
-)
-
-GNOMAD_HT = (
-    'gs://gcp-public-data--gnomad/release/3.1/ht/genomes/gnomad.genomes.v3.1.sites.ht/'
-)
-
-ANCESTRY_SITES_BUCKET = f'{REF_BUCKET}/ancestry/v2'
-ANCESTRY_SITES_MTS = {
-    'all': f'{ANCESTRY_SITES_BUCKET}/gnomad_subset.mt',
-    'nfe': f'{ANCESTRY_SITES_BUCKET}/gnomad_subset_nfe.mt',
-    'test': f'{ANCESTRY_SITES_BUCKET}/gnomad_subset_test.mt',
-    'test_nfe': f'{ANCESTRY_SITES_BUCKET}/gnomad_subset_test_nfe.mt',
-}
-
 SCRIPTS_DIR = 'scripts'
 PACKAGE_DIR = package_name
 
